@@ -1,21 +1,24 @@
 # -*- coding: utf-8 -*-
-import requests
 from .Action import Action
 from .Image import Image
 from .Kernel import Kernel
 from .baseapi import BaseAPI, Error
 from .SSHKey import SSHKey
 
+
 class DropletError(Error):
     """Base exception class for this module"""
     pass
 
+
 class BadKernelObject(DropletError):
     pass
 
+
 class BadSSHKeyFormat(DropletError):
     pass
 
+
 class Droplet(BaseAPI):
     """"Droplet managment
 
@@ -101,7 +104,7 @@ class Droplet(BaseAPI):
 
     def __check_actions_in_data(self, data):
         # reloading actions if actions is provided.
-        if data.has_key(u"actions"):
+        if u"actions" in data:
             self.action_ids = []
             for action in data[u'actions']:
                 self.action_ids.append(action[u'id'])
@@ -111,7 +114,7 @@ class Droplet(BaseAPI):
             Customized version of get_data to perform __check_actions_in_data
         """
         data = super(Droplet, self).get_data(*args, **kwargs)
-        if kwargs.has_key("type"):
+        if "type" in kwargs:
             if kwargs["type"] == "POST":
                 self.__check_actions_in_data(data)
         return data
@@ -124,7 +127,7 @@ class Droplet(BaseAPI):
         droplet = droplets['droplet']
 
         for attr in droplet.keys():
-            setattr(self,attr,droplet[attr])
+            setattr(self, attr, droplet[attr])
 
         for net in self.networks['v4']:
             if net['type'] == 'private':
@@ -132,7 +135,7 @@ class Droplet(BaseAPI):
             if net['type'] == 'public':
                 self.ip_address = net['ip_address']
         if self.networks['v6']:
-            self.ip_v6_address = droplet.networks['v6'][0]['ip_address']
+            self.ip_v6_address = self.networks['v6'][0]['ip_address']
         return self
 
     def power_on(self):
@@ -228,7 +231,7 @@ class Droplet(BaseAPI):
         return self.get_data(
             "droplets/%s/actions/" % self.id,
             type="POST",
-            params={"type":"restore", "image": image_id}
+            params={"type": "restore", "image": image_id}
         )
 
     def rebuild(self, image_id=None):
@@ -237,8 +240,8 @@ class Droplet(BaseAPI):
         Args:
             image_id : int - id of image
         """
-        if self.image_id and not image_id:
-            image_id = self.image_id
+        if not image_id:
+            image_id = self.image['id']
 
         return self.get_data(
             "droplets/%s/actions/" % self.id,
@@ -315,7 +318,7 @@ class Droplet(BaseAPI):
         return self.get_data(
             "droplets/%s/actions/" % self.id,
             type="POST",
-            params={'type' : 'change_kernel', 'kernel': kernel.id}
+            params={'type': 'change_kernel', 'kernel': kernel.id}
         )
 
     def __get_ssh_keys_id(self):
@@ -327,7 +330,7 @@ class Droplet(BaseAPI):
         ssh_keys_id = list()
         for ssh_key in self.ssh_keys:
             if type(ssh_key) in [int, long]:
-                ssh_keys_id.append( int(ssh_key) )
+                ssh_keys_id.append(int(ssh_key))
 
             elif type(ssh_key) == SSHKey:
                 ssh_keys_id.append(ssh_key.id)
@@ -337,7 +340,7 @@ class Droplet(BaseAPI):
                 key.token = self.token
                 results = key.load_by_pub_key(ssh_key)
 
-                if results == None:
+                if results is None:
                     key.public_key = ssh_key
                     key.name = "SSH Key %s" % self.name
                     key.create()
@@ -346,7 +349,9 @@ class Droplet(BaseAPI):
 
                 ssh_keys_id.append(key.id)
             else:
-                raise BadSSHKeyFormat("Droplet.ssh_keys should be a list of IDs or public keys")
+                raise BadSSHKeyFormat(
+                    "Droplet.ssh_keys should be a list of IDs or public keys"
+                )
 
         return ssh_keys_id
 
@@ -358,15 +363,19 @@ class Droplet(BaseAPI):
             assigned to the object.
         """
         for attr in kwargs.keys():
-            setattr(self,attr,kwargs[attr])
+            setattr(self, attr, kwargs[attr])
+
+        # Provide backwards compatibility
+        if not self.size_slug and self.size:
+            self.size_slug = self.size
 
         data = {
-                "name": self.name,
-                "size": self.size_slug,
-                "image": self.image,
-                "region": self.region,
-                "ssh_keys[]": self.__get_ssh_keys_id(),
-            }
+            "name": self.name,
+            "size": self.size_slug,
+            "image": self.image,
+            "region": self.region,
+            "ssh_keys[]": self.__get_ssh_keys_id(),
+        }
 
         if self.backups:
             data['backups'] = True
@@ -388,11 +397,9 @@ class Droplet(BaseAPI):
 
         if data:
             self.id = data['droplet']['id']
-
-        if data[u'droplet'].has_key(u"action_ids"):
+            action_id = data['links']['actions'][0]['id']
             self.action_ids = []
-            for id in data[u'droplet'][u'action_ids']:
-                self.action_ids.append(id)
+            self.action_ids.append(action_id)
 
     def get_events(self):
         """
@@ -407,7 +414,7 @@ class Droplet(BaseAPI):
             This actions can be used to check the droplet's status
         """
         answer = self.get_data(
-            "droplets/%s/actions" % self.id,
+            "droplets/%s/actions/" % self.id,
             type="GET"
         )
 
@@ -456,10 +463,13 @@ class Droplet(BaseAPI):
                     kernel = Kernel(**jsond)
                     kernel.token = self.token
                     kernels.append(kernel)
-                url = data[u'links'][u'pages'].get(u'next')
-                if not url:
-                        break
-                data = self.get_data(data[u'links'][u'pages'].get(u'next'))
+                try:
+                    url = data[u'links'][u'pages'].get(u'next')
+                    if not url:
+                            break
+                    data = self.get_data(url)
+                except KeyError:  # No links.
+                    break
 
         return kernels
 
