@@ -7,6 +7,7 @@ from .Image import Image
 from .Domain import Domain
 from .SSHKey import SSHKey
 from .Action import Action
+from .Account import Account
 
 
 class Manager(BaseAPI):
@@ -20,7 +21,7 @@ class Manager(BaseAPI):
         data = super(Manager, self).get_data(*args, **kwargs)
 
         params = {}
-        if kwargs.has_key("params"):
+        if "params" in kwargs:
             params = kwargs['params']
         unpaged_data = self.__deal_with_pagination(args[0], data, params)
 
@@ -44,11 +45,17 @@ class Manager(BaseAPI):
                     values.append(value)
             data = {}
             data[key] = values
-        except KeyError: # No pages.
+        except KeyError:  # No pages.
             pass
 
         return data
 
+    def get_account(self):
+        """
+            Returns an Account object.
+        """
+        return Account.get_object(api_token=self.token)
+
     def get_all_regions(self):
         """
             This function returns a list of Region object.
