@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """digitalocean API to manage droplets"""
 
-__version__ = "1.0.8"
+__version__ = "1.1"
 __author__ = "Lorenzo Setale ( http://who.is.lorenzo.setale.me/? )"
 __author_email__ = "koalalorenzo@gmail.com"
 __license__ = "See: http://creativecommons.org/licenses/by-nd/3.0/ "
@@ -13,6 +13,7 @@ from .Region import Region
 from .Size import Size
 from .Image import Image
 from .Action import Action
+from .Account import Account
 from .Domain import Domain
 from .Record import Record
 from .SSHKey import SSHKey
